@@ -4,6 +4,24 @@ import requests
 
 SR = "https://some-random-api.ml"
 
+class Image:
+	def __init__(self , image_url: str):
+		self.image_url_ = image_url
+
+	@property
+	def image_url(self):
+		return self.image_url_
+
+	def save(self):
+		try:
+			filename = self.image_url.split('/')[-1]
+			r = requests.get(self.image_url , allow_redirects = True)
+			open(filename , 'wb').write(r.content)
+			return True
+		except:
+			return False
+	
+
 def image(endpoint: str):
 	try:
 		r = requests.request("GET", f"{SR}/img/{endpoint}").json()
